@@ -2,7 +2,7 @@
 --
 -- Gitano command processing
 --
--- Copyright 2012-2017 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- Copyright 2012-2019 Daniel Silverstone <dsilvers@digital-scurf.org>
 -- All rights reserved.
 --
 -- Redistribution and use in source and binary forms, with or without
@@ -398,11 +398,17 @@ View and manipulate the configuration of a repository.
   then you should set the filter exactly to `foo.*` which will cause
   the show command to expand list keys into the form `foo.i_N` where N
   is the index in the list.
+
+  For example: `config sampler set project.readers.* alice`,
+  and `config sampler set project.readers.* bob` will add users alice and
+  bob to the `project.readers` list for the sampler.git repository.
+
 * config <reponame> set key value
   Set the given configuration key to the given value.  If the key ends
   in `.*` then the system will add the given value to the end of the
   list represented by the key.  To replace a specific entry, set the
   specific `i_N` entry to the value you want to replace it.
+
 * config <reponame> {del,delete,rm} key
   Removes the given key from the configuration set.  If the key ends in `.*`
   then the system will remove all configuration values below that prefix.
@@ -531,6 +537,15 @@ local function builtin_config_run(conf, repo, cmdline, env)
          end
          log.stdout(key .. ": " .. value)
       end
+      if #slist == 0 then
+         local keys = {}
+         for i = 4, #cmdline do
+            keys[#keys+1] = "'" .. cmdline[i] .. "'"
+         end
+         keys = table.concat(keys, ", ")
+         log.error("Configuration keys not found: " .. keys)
+         return "exit", 1
+      end
    elseif cmdline[3] == "set" then
       local key, value = cmdline[4], cmdline[5]
       local vtype, rest = value:match(pattern.CONF_SET_TYPE_PREFIX)
