@@ -5,7 +5,7 @@
 -- Note: This is only the admin repo management, not the
 -- generic repository rules management (see gitano.lace for that).
 --
--- Copyright 2012-2017 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- Copyright 2012-2019 Daniel Silverstone <dsilvers@digital-scurf.org>
 -- All rights reserved.
 --
 -- Redistribution and use in source and binary forms, with or without
@@ -42,6 +42,7 @@ local pat = require 'gitano.patterns'
 local luxio = require 'luxio'
 local sio = require 'luxio.simple'
 local clod = require 'clod'
+local util = require 'gitano.util'
 
 local pcall = pcall
 local pairs = pairs
@@ -163,10 +164,7 @@ local function parse_admin_config(commit)
          if not (keytype and keydata and keytag) then
             return nil, i18n.expand("ERROR_BAD_KEY_SMELL", {filename=filename})
          end
-         if (keytype ~= "ssh-rsa") and (keytype ~= "ssh-dss") and
-            (keytype ~= "ecdsa-sha2-nistp256") and
-            (keytype ~= "ecdsa-sha2-nistp384") and
-         (keytype ~= "ecdsa-sha2-nistp521") then
+         if util.ssh_type_is_invalid(keytype) then
             return nil, i18n.expand("ERROR_BAD_KEY_TYPE",
                                     {keytype=keytype, filename=filename})
          end
@@ -355,8 +353,11 @@ local function get_default_hook_content(conf, filename)
 ]], conf.commit.sha .. "::[[" .. filename .. "]]"
 end
 
+local SSH_KEYS_MARKER_START = "### Gitano Keys ###"
+local SSH_KEYS_MARKER_END = "### End Gitano Keys ###"
+
 local function generate_ssh_config(conf)
-   local ret = {"","### Gitano Keys ###"}
+   local ret = {SSH_KEYS_MARKER_START}
    for u, t in pairs(conf.users) do
       for ktag, keytab in pairs(t.keys) do
          log.debug(i18n.expand("DEBUG_ADDING_SSH_KEY", {user=u, key=ktag}))
@@ -365,7 +366,7 @@ local function generate_ssh_config(conf)
                   format(lib_bin_path, repo_path, u, ktag, keytab.data))
       end
    end
-   ret[#ret+1] = "### End Gitano Keys ###"
+   ret[#ret+1] = SSH_KEYS_MARKER_END
    ret[#ret+1] = ""
    return tconcat(ret, "\n")
 end
@@ -383,6 +384,30 @@ local function update_ssh_keys(conf, ssh_path)
       ssh_path = home .. "/.ssh/authorized_keys"
    end
 
+   local prefix, suffix = "", ""
+   local rfh, err = sio.open(ssh_path, "r")
+   if rfh then
+      local accum = {}
+      local l = rfh:read("*l")
+      while l ~= nil do
+         if l == SSH_KEYS_MARKER_START then
+            accum[#accum+1] = ""
+            prefix = tconcat(accum, "\n")
+            accum = {}
+         elseif l == SSH_KEYS_MARKER_END then
+            accum = {}
+         else
+            accum[#accum+1] = l
+         end
+         l = rfh:read("*l")
+      end
+      if prefix ~= "" then
+         accum[#accum+1] = ""
+         suffix = tconcat(accum, "\n")
+      end
+      rfh:close()
+   end
+
    local create_path = ssh_path .. ".new"
 
    local cfh, err = sio.open(create_path, "cew")
@@ -391,7 +416,9 @@ local function update_ssh_keys(conf, ssh_path)
       log.fatal(i18n.expand("ERROR_UNABLE_TO_CREATE", {path=create_path}))
    end
 
+   cfh:write(prefix)
    cfh:write(ssh_config)
+   cfh:write(suffix)
    cfh:close()
 
    local ret, errno = luxio.rename(create_path, ssh_path)
