@@ -33,14 +33,13 @@
 local util = require "gitano.util"
 local log = require "gitano.log"
 local i18n = require "gitano.i18n"
+local pat = require "gitano.patterns"
 
 local luxio = require "luxio"
 local sio = require "luxio.simple"
 
 local gfind = string.gfind
 
-local plugin_name_pattern = "^([^_]+)%.lua$"
-
 local function find_plugins(path)
    local ret = {}
    for _, entry in ipairs(path) do
@@ -50,7 +49,7 @@ local function find_plugins(path)
                                  {dir=entry, reason=err}))
       else
          for filename, fileinfo in dirp:iterate() do
-            local plugin_name = filename:match(plugin_name_pattern)
+            local plugin_name = filename:match(pat.PLUGIN_NAME)
             if plugin_name then
                if not ret[plugin_name] then
                   ret[plugin_name] = entry
