@@ -40,6 +40,7 @@ local config = require 'gitano.config'
 local util = require 'gitano.util'
 local lace = require 'gitano.lace'
 local i18n = require 'gitano.i18n'
+local pat = require 'gitano.patterns'
 local clod = require 'clod'
 
 local base_rules = [[
@@ -455,8 +456,8 @@ function repo_method:populate_context(context)
    if not self.is_nascent then
       local lists_to_add = {}
       for k, v in self.project_config:each() do
-         if k:match("%.i_[0-9]+$") then
-            lists_to_add[k:gsub("%.i_[0-9]+$", "")] = true
+         if k:match(pat.CONF_ARRAY_INDEX) then
+            lists_to_add[k:match(pat.CONF_ARRAY_INDEX)] = true
          else
             local confkey = "config/" .. k:gsub("%.", "/")
             context[confkey] = v
@@ -489,6 +490,11 @@ function repo_method:realise()
    self.git = r
    self.is_nascent = nil
 
+   r, msg = self.git:update_server_info()
+   if not r then
+      return false, msg
+   end
+
    -- Finally, we're not nascent, validate the repo
    return self:run_checks()
 end
@@ -507,7 +513,7 @@ function repo_method:conf_set_and_save(conf, newvalue, author, committer)
 end
 
 function repo_method:set_head(newhead, author, committer)
-   if not newhead:match("^refs/") then
+   if not newhead:match(pat.REF_IS_NORMALISED) then
       newhead = "refs/heads/" .. newhead
    end
    local oldhead = self:conf_get "project.head"
@@ -563,15 +569,27 @@ function repo_method:destroy_self(call_me)
    return true
 end
 
+local function normalise_repo_path(reponame)
+   -- Inject a leading '/'
+   reponame = "/" .. reponame
+   -- Remove any spaces, tabs, newlines or nulls
+   reponame = reponame:gsub("[%s%z]+", "")
+   -- Remove any '.' which follows a '/'
+   reponame = reponame:gsub("/%.+", "/")
+   -- simplify any sequence of '/' to a single '/'
+   reponame = reponame:gsub("/+", "/")
+   -- Remove any leading or trailing /
+   reponame = reponame:match("^/*(.-)/*$")
+   -- Remove trailing .git if present.
+   if reponame:match("."..pat.GIT_REPO_SUFFIX) then
+      reponame = reponame:match(pat.GIT_REPO_NAME_MATCH)
+   end
+   return reponame
+end
+
 function repo_method:rename_to(somename)
    -- Same cleanup as in find...
-   if somename:match(".%.git$") then
-      somename = somename:match("^(.+)%.git$")
-   end
-   -- Remove any '.'
-   somename = somename:gsub("%.", "")
-   -- Remove any leading or trailing /
-   somename = somename:match("^/*(.-)/*$")
+   somename = normalise_repo_path(somename)
 
    local newpath = self.fs_path({name=somename,config=self.config})
 
@@ -674,7 +692,7 @@ function repo_method:update_modified_date(shas)
    if f then
       local s = f:read("*l")
       if s then
-         local cur_mod_time, cur_mod_offset = s:find("^([0-9]+) ([+-][0-9]+)$")
+         local cur_mod_time, cur_mod_offset = s:find(pat.PARSE_TIME_AND_TZOFFSET)
          if cur_mod_time then
             update_based_on(cur_mod_time, cur_mod_offset)
          end
@@ -825,20 +843,7 @@ local function find_repository(config, reponame)
    --
    -- If the repository exists, then it is examined and brought up-to-date
    -- with any global config changes before being returned.
-   -- Inject a leading '/'
-   reponame = "/" .. reponame
-   -- Remove any spaces, tabs, newlines or nulls
-   reponame = reponame:gsub("[%s%z]+", "")
-   -- Remove any '.' which follows a '/'
-   reponame = reponame:gsub("/%.+", "/")
-   -- simplify any sequence of '/' to a single '/'
-   reponame = reponame:gsub("/+", "/")
-   -- Remove any leading or trailing /
-   reponame = reponame:match("^/*(.-)/*$")
-   -- Remove trailing .git if present.
-   if reponame:match(".%.git$") then
-      reponame = reponame:match("^(.+)%.git$")
-   end
+   reponame = normalise_repo_path(reponame)
 
    -- Construct the repo
    local repo = setmetatable({config = config, name = reponame}, repo_meta)
@@ -899,12 +904,12 @@ local function foreach_repository(conf, callback, filterfn)
       repeat
          e, i = luxio.readdir(dirp)
          if e == 0 then
-            if i.d_name:find("%.git$") then
+            if i.d_name:match(pat.GIT_REPO_SUFFIX) then
                -- Might be a repo, save for later
                all_repos[#all_repos+1] = (util.path_join(prefix, i.d_name)
                                          ):gsub("^/", "")
             else
-               if i.d_name:find("^[^%.]") then
+               if not i.d_name:match(pat.DOTFILE) then
                   recurse[#recurse+1] = i.d_name
                end
             end
