@@ -36,6 +36,7 @@ local supple = require 'supple'
 local log = require 'gitano.log'
 local config = require 'gitano.config'
 local i18n = require 'gitano.i18n'
+local pat = require 'gitano.patterns'
 
 local repo_proxies = {}
 local proxied_repo = {}
@@ -112,7 +113,7 @@ local function load_repo_module(fromrepo, prefix, module)
 end
 
 local function load_module_src(modname)
-   local pfx, mod = modname:match("^([^%.]+)%.(.+)$")
+   local pfx, mod = modname:match(pat.SUPPLE_MODULE_LOAD_MATCH)
    if not (pfx and mod) then
       error(i18n.expand("ERROR_NOT_RIGHT_NAME_FORMAT", {modname=modname}))
    end
