@@ -219,10 +219,7 @@ local function builtin_sshkey_run(conf, _, cmdline, env)
          return "exit", 1
       end
 
-      if (keytype ~= "ssh-rsa") and (keytype ~= "ssh-dss") and
-         (keytype ~= "ecdsa-sha2-nistp256") and
-         (keytype ~= "ecdsa-sha2-nistp384") and
-      (keytype ~= "ecdsa-sha2-nistp521") then
+      if util.ssh_type_is_invalid(keytype) then
          log.error("Unknown key type", keytype)
          return "exit", 1
       end
