@@ -584,6 +584,18 @@ local function unlockfile(fh)
    fh:close()
 end
 
+local function ssh_type_is_invalid(keytype)
+   if (keytype ~= "ssh-rsa") and
+      (keytype ~= "ssh-dss") and
+      (keytype ~= "ecdsa-sha2-nistp256") and
+      (keytype ~= "ecdsa-sha2-nistp384") and
+      (keytype ~= "ecdsa-sha2-nistp521") and
+      (keytype ~= "ssh-ed25519") then
+      return true
+   end
+   return false
+end
+
 return {
    parse_cmdline = _parse_cmdline,
 
@@ -623,4 +635,5 @@ return {
 
    lockfile = lockfile,
    unlockfile = unlockfile,
+   ssh_type_is_invalid = ssh_type_is_invalid,
 }
